@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import errno
 import json
 import logging as log
 # python imports
@@ -19,7 +20,7 @@ def initialize(app_env={}, args=None):
     if app_env:
         set_env(app_env)
     parse_command_line(args)
-    config_file = os.getcwd() +  "/config/%s.conf" % get_env()
+    config_file = os.path.join(os.getcwd(), 'config', '%s.conf') % get_env()
     create_config_file(config_file)
     parse_config_file(config_file)
 
@@ -28,8 +29,15 @@ def create_config_file(file_path):
         import middleware
         path = os.path.dirname(middleware.__file__)
         config = open(path + "/config/example.conf", "r")
+        if not os.path.exists(os.path.dirname(file_path)):
+            try:
+                os.makedirs(os.path.dirname(file_path))
+            except OSError as exc:  # Guard against race condition
+                if exc.errno != errno.EEXIST:
+                    raise
         with open(file_path, "w") as f:
             f.write(config.read())
+        f.close()
 
 def get_env():
     if options.env:
@@ -66,7 +74,7 @@ define('root_url', default='localhost')
 define('mysql_user', default='root')
 define('mysql_password', default='')
 define('mysql_2_password', default='')
-define('schema_user', default='')
+define('schema_user', default='root')
 define('schema_password', default='')
 
 # Mysql setup etc
@@ -89,7 +97,7 @@ define('selectHR_db_host', default='')
 define('selectHR_db_user', default='')
 define('selectHR_db_password', default='')
 define('selectHR_driver', default='ODBC Driver 13 for SQL Server')
-define('selectHR_audit_db_name', default='SELECTHR_Persist')
+define('selectHR_audit_db_name', default='')
 
 define('slack_api_tokens_dict', default={})
 define('save_picture_path', default='')
@@ -124,11 +132,7 @@ environments = {
     },
 }
 
-LOGIN_COOKIE_NAME = 'secportal_login'
-RESET_TOKEN_LENGTH = 15
-SIGNUP_COOKIE_NAME = 'secportal_signup'
 
 PER_PAGE = 50  # default number of rows in a paginated query
 PAGE_SIZES = [10, 20, 50, 100, 200]
 
-CERTIFICATE = 'OctopusLabs.pem'
